@@ -135,7 +135,13 @@ impl DittoBuilder {
             .ok_or_else(|| DittoError::new(ErrorKind::Config, "No Identity specified"))?;
         let auth_client_ref: &ffi_sdk::AuthClient = &identity.auth_client();
         let uninit_ditto = unsafe { ffi_sdk::uninitialized_ditto_make(c_data_dir.as_ref()) };
-        let boxed_ditto = unsafe { ffi_sdk::ditto_make(uninit_ditto, auth_client_ref) };
+        let boxed_ditto = unsafe {
+            ffi_sdk::ditto_make(
+                uninit_ditto,
+                auth_client_ref,
+                ffi_sdk::HistoryTracking::Disabled,
+            )
+        };
         let ditto: Arc<BoxedDitto> = Arc::new(boxed_ditto);
         let site_id: SiteId = identity.site_id();
         let store = Store::new(ditto.retain());
@@ -185,7 +191,7 @@ impl DittoBuilder {
                     //   - same layout,
                     //   - we never upgrade the weak within this scope.
                     crate::utils::transmute_by_ref::<
-                        arc::Weak<::core::mem::MaybeUninit<DittoFields>>,
+                        _, // arc::Weak<::core::mem::MaybeUninit<DittoFields>>,
                         arc::Weak<DittoFields>,
                     >(weak_fields)
                 };
